=====
Usage
=====

Run::

	$ recognizer

Write a number on a clean peace of paper. Position it inside the green box in a way that the number is focused. Press **r** to recognize the number. Press **q** to quit the program.


For more information on the model used to classify the digits check `here <https://github.com/condereis/kaggle-mnist>`_.